@@ -34,7 +34,7 @@ SKILL_ALIASES = {
     "Thieving": ["Thief"],
     "Slayer": ["Slay"],
     "Farming": ["Farm"],
-    "Runecrafting": ["RC"],
+    "Runecraft": ["RC", "Runecrafting"],
     "Hunter": ["Hunt"],
     "Construction": ["Cons"],
     "Clue Scrolls (all)": ["Clue", "Clue [All]"],
@@ -45,12 +45,45 @@ SKILL_ALIASES = {
     "Clue Scrolls (elite)": ["Elite", "Clue [Elite]"],
     "Clue Scrolls (master)": ["Master", "Clue [Master]"],
     "PvP Arena - Rank": ["Arena"],
+    "Colosseum Glory": ["Colosseum", "Glory"],
+    "Collections Logged": ["Col", "Collog"],
+    "Alchemical Hydra": ["Hydra"],
+    "Abyssal Sire": ["Sire"],
     "Barrows Chests": ["Barrows"],
+    "Commander Zilyana": ["Sara", "Saradomin", "Zilyana"],
+    "Corporeal Beast": ["Corp"],
+    "Chambers of Xeric": ["CoX"],
+    "Chambers of Xeric: Challenge Mode": ["CoX Hard"],
+    "Dagannoth Prime": ["Prime"],
+    "Dagannoth Rex": ["Rex"],
+    "Dagannoth Supreme": ["Supreme"],
+    "Doom of Mokhaiotl": ["Delve", "Doom"],
+    "Duke Sucesllus": ["Duke"],
+    "General Graardor": ["Graardor", "Bandos"],
+    "Giant Mole": ["Mole"],
+    "Grotesque Guardians": ["GG"],
+    "Kalphite Queen": ["KQ"],
+    "King Black Dragon": ["KBD"],
+    "Kree'arra": ["Kree", "Arma", "Armadyl"],
+    "K'ril Tsutsaroth": ["Kril", "Zammy", "Zamorak"],
+    "Phantom Muspah": ["Muspah"],
+    "Phosani's Nightmare": ["Phosani"],
+    "Sol Heredit": ["Sol"],
+    "The Gauntlet": ["Gauntlet"],
+    "The Corrupted Gauntlet": ["CG", "Corrupted", "Corrupted Gauntlet"],
+    "The Hueycoatl": ["Huey"],
+    "The Leviathan": ["Leviathan"],
+    "The Whisperer": ["Whisperer"],
+    "Theatre of Blood": ["ToB"],
+    "Theatre of Blood: Hard Mode": ["ToB Hard"],
+    "Tombs of Amascut": ["ToA"],
+    "Tombs of Amascut: Expert Mode": ["ToA Expert"],
+    "TzTok-Jad": ["Jad"],
+    "TzKal-Zuk": ["Inferno", "Zuk"],
 }
 
-HISCORES_HOME_PATH = "m=hiscore_oldschool/overall.ws"
-HISCORES_PATH = "m=hiscore_oldschool/index_lite.ws"
-HISCORES_LEAGUES_PATH = "m=hiscore_oldschool_seasonal/index_lite.ws"
+HISCORES_PATH = "m=hiscore_oldschool/index_lite.json"
+HISCORES_LEAGUES_PATH = "m=hiscore_oldschool_seasonal/index_lite.json"
 NEWS_PATH = "m=news/latest_news.rss"
 GE_PATH = "m=itemdb_oldschool/api/catalogue/detail.json"
 
@@ -105,51 +138,6 @@ def _request(path: str, _retries: int = DEFAULT_RETRIES,
     raise TimeoutError("hiscore request timed out")
 
 
-def _parse_scores(text: str, skills: typing.List[Skill]) -> dict:
-    scores = {}
-
-    for idx, row in enumerate(csv.reader(text.splitlines())):
-        if not 2 <= len(row) <= 3:
-            raise rsapi.ParseError(
-                "Hiscores has unexpected formatting. Update needed?"
-            ) from None
-
-        try:
-            rank = int(row[0])
-            level = int(row[1])
-        except (TypeError, ValueError):
-            raise rsapi.ParseError(
-                "Hiscores has unexpected formatting. Update needed?"
-            ) from None
-
-        # Acitivities don't have exp
-        try:
-            exp = int(row[2])
-        except (TypeError, ValueError, IndexError):
-            exp = None
-
-        try:
-            skill = skills[idx]
-        except IndexError:
-            print(idx)
-            raise rsapi.ParseError(
-                "Hiscores has unexpected amount of entries. Update needed?"
-            ) from None
-
-        scores[skill["name"]] = {
-            "rank": rank,
-            "level": level,
-            "exp": exp,
-        }
-
-    if len(scores) != len(skills):
-        raise rsapi.ParseError(
-            "Hiscores has unexpected amount of entries. Update needed?"
-        )
-
-    return scores
-
-
 def _parse_news(text: str) -> dict:
     def unwrap(node: typing.Optional[typing.Any]) -> typing.Any:
         if node is None:
@@ -198,56 +186,45 @@ def _parse_news(text: str) -> dict:
     return parse_channel(unwrap(root.find("./channel")))
 
 
-def _parse_skills(text: str) -> typing.List[Skill]:
-    skills: typing.List[Skill] = []
-    soup = bs4.BeautifulSoup(text, 'html.parser')
-
-    div = soup.find('div', {"id": "contentCategory"})
-    if not isinstance(div, bs4.Tag):
-        raise rsapi.ParseError("Unable to parse hiscores page for skills")
-
-    for skill in div.find_all("a"):
-        skill_name = skill.text.strip()
-        skills.append(Skill(
-            name=skill_name,
-            activity="activity-link" in skill["class"],
-            aliases=SKILL_ALIASES.get(skill_name),
-        ))
-
-    # FIXUP: League points are not visible on hiscore main page when league is
-    # not active. Insert league points after last skill to align with API data
-    # from hiscores.
-    # FIXME 3.10: Use bisect_left with key=
-    for idx, skill in enumerate(skills):
-        if skill["activity"]:
-            skills.insert(
-                idx,
-                Skill(name="League Points", activity=True, aliases=None)
-            )
-            break
-    else:
-        raise RuntimeError("Internal error - expected to find activities")
-
-    return skills
-
-
-def skills() -> typing.List[Skill]:
-    with _request(HISCORES_HOME_PATH) as resp:
-        return _parse_skills(resp.text)
-
-
 def _hiscores_raw(player: str, path: str) -> str:
     try:
         with _request(path, player=player) as resp:
-            return resp.text
+            return resp.json()
     except requests.HTTPError as err:
         if err.response.status_code == requests.codes["not_found"]:
             raise rsapi.PlayerNotFound(f"Player {player} not found") from None
         raise err
 
 
-def _hiscores(player: str, path: str):
-    return _parse_scores(_hiscores_raw(player, path), skills())
+def _hiscores(player: str, path: str) -> str:
+    scores = _hiscores_raw(player, path)
+    return {
+        skill["name"]: {
+            "rank": skill["rank"],
+            "level": skill.get("level", skill.get("score")),
+            "exp": skill.get("xp"),
+        } for skill in scores["skills"] + scores["activities"]
+    }
+
+
+def skills() -> typing.List[Skill]:
+    scores = _hiscores_raw("jakop", HISCORES_PATH)
+    ret = []
+
+    for skill in scores["skills"]:
+        ret.append({
+            "name": skill["name"],
+            "activity": False,
+            "aliases": SKILL_ALIASES.get(skill["name"]),
+        })
+    for skill in scores["activities"]:
+        ret.append({
+            "name": skill["name"],
+            "activity": True,
+            "aliases": SKILL_ALIASES.get(skill["name"]),
+        })
+
+    return ret
 
 
 def hiscores(player: str) -> dict:
