@@ -47,6 +47,12 @@ def test_items():
     assert items[0]["highalch"] == 21, "Expected to find item highalch"
 
 
+def test_ge():
+    items = osrs.ge("dragon bones")
+    assert len(items) > 1
+    assert any(i["name"] == "Dragon bones" for i in items.values())
+
+
 def test_item_not_found():
     with pytest.raises(rsapi.ItemError):
         osrs.items("Not lightbearer")
